@@ -15,7 +15,7 @@
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: gstinterfacesperl.h,v 1.1 2005/09/28 16:10:47 kaffeetisch Exp $
+ * $Id: gstinterfacesperl.h,v 1.2 2006/01/24 19:53:42 kaffeetisch Exp $
  */
 
 #ifndef _GSTINTERFACES2PERL_H_
@@ -23,7 +23,8 @@
 
 #include <gst2perl.h>
 
-#include <gst/propertyprobe/propertyprobe.h>
+#include <gst/interfaces/propertyprobe.h>
+#include <gst/interfaces/xoverlay.h>
 
 #include "gstinterfacesperl-autogen.h"
 
